==> jmb.store-0.1.tar.gz: jmb.store-0.1/jmb/store/dashboard.py <==
from django.utils.translation import ugettext_lazy as _

from admin_tools.dashboard import modules

from jmb.product.models import Product
from jmb.store.models import Store

class StoreDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Stores",
            'display': "tabs",
            'children': [
                StoreModels(),
                StoreSettings(),
            ]
        }
        super(StoreDashboard, self).__init__(**kwargs)

class StoreModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Models"),
            'models': (
                'store.models.Store', 'store.models.StoreAddress', 'store.models.StoreDocument',
                'store.models.StoreDocumentNumber', 'store.models.StoreCause',
            ),
        }
        super(StoreModels, self).__init__(**kwargs)

class StoreSettings(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Settings"),
            'models':['store.models.Settings',],
            }
        super(StoreSettings, self).__init__(**kwargs)

class Stores(modules.DashboardModule):
    def __init__(self, title, template='admin_tools/dashboard/stores.html',
                 order_by=None, limit=10, qs=Store.objects.all(), extra_filters={},
                 children=None, **kwargs
    ):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(Stores, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs

==> jmb.store-0.2.tar.gz: jmb.store-0.2/jmb/store/dashboard.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.store.models import Store
from jmb.core.admin import dashboard as jmb_dashboard

class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Stores",
            'display': "tabs",
            'children': [Models(),]
        }
        super(DefaultDashboard, self).__init__(**kwargs)

class StoreDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Stores",
            'display': "tabs",
            'children': [Models(),]
        }
        super(StoreDashboard, self).__init__(**kwargs)

class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Main Models"),
            'models': ('jmb.store.models.*',),
            }
        super(Models, self).__init__(**kwargs)


class StoreSettings(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Settings"),
            'models':['store.models.Settings',],
            }
        super(StoreSettings, self).__init__(**kwargs)

class Stores(modules.DashboardModule):
    def __init__(self, title, template='admin_tools/dashboard/stores.html',
                 order_by=None, limit=10, qs=Store.objects.all(), extra_filters={},
                 children=None, **kwargs
    ):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(Stores, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs

class DefaultAppDashboard(AppIndexDashboard):
#    class Media:
#        css = ('office_thunder/css/dashboard.css',)
#
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 2

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )
# Used in /admin
jmb_dashboard.register_group(StoreDashboard, 'jmb.store')
# Used in /admin/Office
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.store')
